@@ -6,3 +6,5 @@ from frostaura.engines.asset_calculations_engine import IAssetCalculationsEngine
 from frostaura.engines.asset_calculations_engine__simple import SimpleAssetCalculationsEngine
 from frostaura.engines.asset_projection_engine import IAssetProjectionEngine
 from frostaura.engines.asset_projection_engine__simple import SimpleAssetProjectionEngine
+from frostaura.engines.visualization_engine import IVisualizationEngine
+from frostaura.engines.frostaura_visualization_engine import FrostAuraVisualizationEngine
